@@ -47,6 +47,9 @@ class GenericRule extends Rule
     public function getHash()
     {
         $data = unpack('ihash', (string) hash(\PHP_VERSION_ID > 80100 ? 'xxh3' : 'sha1', implode(',', $this->literals), true));
+        if (false === $data) {
+            throw new \RuntimeException('Failed unpacking: '.implode(', ', $this->literals));
+        }
 
         return $data['hash'];
     }
