@@ -552,11 +552,14 @@ class Locker
             $sourceRef = $package->getSourceReference() ?: $package->getDistReference();
             switch ($sourceType) {
                 case 'git':
-                    GitUtil::cleanEnv();
+                    GitUtil::cleanEnv($this->process);
 
-                    $command = array_merge(['git', 'log', '-n1', '--pretty=%ct', (string) $sourceRef], GitUtil::getNoShowSignatureFlags($this->process));
-                    if (0 === $this->process->execute($command, $output, $path) && Preg::isMatch('{^\s*\d+\s*$}', $output)) {
-                        $datetime = new \DateTime('@'.trim($output), new \DateTimeZone('UTC'));
+                    $command = GitUtil::buildRevListCommand($this->process, array_merge(['-n1', '--format=%ct', (string) $sourceRef], GitUtil::getNoShowSignatureFlags($this->process)));
+                    if (0 === $this->process->execute($command, $output, $path)) {
+                        $output = trim(GitUtil::parseRevListOutput($output, $this->process));
+                        if (Preg::isMatch('{^\s*\d+\s*$}', $output)) {
+                            $datetime = new \DateTime('@'.trim($output), new \DateTimeZone('UTC'));
+                        }
                     }
                     break;
 
