@@ -133,6 +133,17 @@ class PluginManager
         return $this->plugins;
     }
 
+    /**
+     * Gets all currently active plugin instances
+     *
+     * @internal
+     * @return array<string> Plugin package names which are currently active
+     */
+    public function getRegisteredPlugins(): array
+    {
+        return array_keys($this->registeredPlugins);
+    }
+
     /**
      * Gets global composer or null when main composer is not fully loaded
      */
