@@ -675,7 +675,7 @@ class ComposerRepository extends ArrayRepository implements ConfigurableReposito
 
                 $promises[] = $this->startCachedAsyncDownload($name, $name)
                     ->then(static function (array $spec) use (&$advisories, &$namesFound, &$packageConstraintMap, $name, $create): void {
-                        [$response, ] = $spec;
+                        [$response] = $spec;
 
                         if (!isset($response['security-advisories']) || !is_array($response['security-advisories'])) {
                             return;
@@ -683,12 +683,12 @@ class ComposerRepository extends ArrayRepository implements ConfigurableReposito
 
                         $namesFound[$name] = true;
                         if (count($response['security-advisories']) > 0) {
-                            $advisories[$name] = array_filter(array_map(
+                            $advisories[$name] = array_values(array_filter(array_map(
                                 static function ($data) use ($name, $create) {
                                     return $create($data, $name);
                                 },
                                 $response['security-advisories']
-                            ));
+                            )));
                         }
                         unset($packageConstraintMap[$name]);
                     });
@@ -719,18 +719,18 @@ class ComposerRepository extends ArrayRepository implements ConfigurableReposito
                     continue;
                 }
                 if (count($list) > 0) {
-                    $advisories[$name] = array_filter(array_map(
+                    $advisories[$name] = array_values(array_filter(array_map(
                         static function ($data) use ($name, $create) {
                             return $create($data, $name);
                         },
                         $list
-                    ));
+                    )));
                 }
                 $namesFound[$name] = true;
             }
         }
 
-        return ['namesFound' => array_keys($namesFound), 'advisories' => array_filter($advisories)];
+        return ['namesFound' => array_keys($namesFound), 'advisories' => array_filter($advisories, static function ($adv): bool { return \count($adv) > 0; })];
     }
 
     public function getProviders(string $packageName)
@@ -1298,7 +1298,6 @@ class ComposerRepository extends ArrayRepository implements ConfigurableReposito
     }
 
     /**
-     * @param string $url
      * @return non-empty-string
      */
     private function canonicalizeUrl(string $url): string
